==> snslambda-1.51.0-sources.jar: software/amazon/awsconstructs/services/snslambda/SnsToLambda.java <==
package software.amazon.awsconstructs.services.snslambda;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.8.0 (build 4a047ac)", date = "2020-07-13T22:27:46.443Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.snslambda.$Module.class, fqn = "@aws-solutions-constructs/aws-sns-lambda.SnsToLambda")
public class SnsToLambda extends software.amazon.awscdk.core.Construct {

    protected SnsToLambda(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SnsToLambda(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public SnsToLambda(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.snslambda.SnsToLambdaProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return this.jsiiGet("lambdaFunction", software.amazon.awscdk.services.lambda.Function.class);
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.Topic getSnsTopic() {
        return this.jsiiGet("snsTopic", software.amazon.awscdk.services.sns.Topic.class);
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.snslambda.SnsToLambda}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.snslambda.SnsToLambda> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.snslambda.SnsToLambdaProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.snslambda.SnsToLambdaProps.Builder();
        }

        /**
         * Use a KMS Key, either managed by this CDK app, or imported.
         * <p>
         * If importing an encryption key, it must be specified in
         * the encryptionKey property for this construct.
         * <p>
         * Default: - true (encryption enabled, managed by this CDK app).
         * <p>
         * @return {@code this}
         * @param enableEncryption Use a KMS Key, either managed by this CDK app, or imported. This parameter is required.
         */
        public Builder enableEncryption(final java.lang.Boolean enableEncryption) {
            this.props.enableEncryption(enableEncryption);
            return this;
        }

        /**
         * An optional, imported encryption key to encrypt the SNS topic with.
         * <p>
         * Default: - not specified.
         * <p>
         * @return {@code this}
         * @param encryptionKey An optional, imported encryption key to encrypt the SNS topic with. This parameter is required.
         */
        public Builder encryptionKey(final software.amazon.awscdk.services.kms.Key encryptionKey) {
            this.props.encryptionKey(encryptionKey);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final java.lang.Object lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * Optional user provided properties to override the default properties for the SNS topic.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param topicProps Optional user provided properties to override the default properties for the SNS topic. This parameter is required.
         */
        public Builder topicProps(final java.lang.Object topicProps) {
            this.props.topicProps(topicProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.snslambda.SnsToLambda}.
         */
        @Override
        public software.amazon.awsconstructs.services.snslambda.SnsToLambda build() {
            return new software.amazon.awsconstructs.services.snslambda.SnsToLambda(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> snslambda-1.127.0-sources.jar: software/amazon/awsconstructs/services/snslambda/SnsToLambda.java <==
package software.amazon.awsconstructs.services.snslambda;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.46.0 (build cd08c55)", date = "2021-11-28T01:16:31.944Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.snslambda.$Module.class, fqn = "@aws-solutions-constructs/aws-sns-lambda.SnsToLambda")
public class SnsToLambda extends software.amazon.awscdk.core.Construct {

    protected SnsToLambda(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SnsToLambda(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public SnsToLambda(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.snslambda.SnsToLambdaProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.Topic getSnsTopic() {
        return software.amazon.jsii.Kernel.get(this, "snsTopic", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.sns.Topic.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.snslambda.SnsToLambda}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.snslambda.SnsToLambda> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.snslambda.SnsToLambdaProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.snslambda.SnsToLambdaProps.Builder();
        }

        /**
         * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * Existing instance of SNS Topic object, providing both this and topicProps will cause an error..
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param existingTopicObj Existing instance of SNS Topic object, providing both this and topicProps will cause an error.. This parameter is required.
         */
        public Builder existingTopicObj(final software.amazon.awscdk.services.sns.Topic existingTopicObj) {
            this.props.existingTopicObj(existingTopicObj);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * Optional user provided properties to override the default properties for the SNS topic.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param topicProps Optional user provided properties to override the default properties for the SNS topic. This parameter is required.
         */
        public Builder topicProps(final software.amazon.awscdk.services.sns.TopicProps topicProps) {
            this.props.topicProps(topicProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.snslambda.SnsToLambda}.
         */
        @Override
        public software.amazon.awsconstructs.services.snslambda.SnsToLambda build() {
            return new software.amazon.awsconstructs.services.snslambda.SnsToLambda(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
